@@ -13,6 +13,7 @@ def main():
         type=argparse.FileType('r'),
         help='A list of URLs separated by newline characters'
     )
+    parser.add_argument('-s', '--sessionid', help='The session cookie id')
     args = parser.parse_args()
 
     urls = set()
@@ -26,7 +27,10 @@ def main():
     bc = basketcase.BasketCase()
 
     if bc.authenticator.needs_authentication():
-        bc.authenticator.login()
+        if args.sessionid:
+            bc.authenticator.login_with_cookie(args.sessionid)
+        else:
+            bc.authenticator.login()
 
     bc.fetch(urls)
 
